Exception: Speck::Exception

Inherits:
StandardError
  • Object
show all
Defined in:
lib/speck.rb

Overview

A root class, and container class, for Speck exceptions.

Constant Summary collapse

NoEnvironment =

Raised any time checks are run outside of a Speck

Class.new self
CheckFailed =

Raised when a Check fails

Class.new self